@@ -35,6 +35,7 @@
         $album = new album($parent_album_id);
     }
     $album->lookup($user);
+    $obj=&$album;
     $ancestors = $album->get_ancestors();
     $children = $album->get_children($user);
 
@@ -53,12 +54,14 @@
 <?php
     }
 ?>
-        <?php echo translate("albums") . "\n" ?>
+        <?php echo $title . "\n" ?>
     </h1>
 <?php
     if($user->is_admin()) {
         include("selection.inc.php");
     }
+    include("show_page.inc.php");
+    if($show_orig) {
 ?>
     <div class="main">
 <?php
@@ -159,6 +162,16 @@
         }
     }
     if ($children) {
+        if($_view=="tree" && JAVASCRIPT) {
+?>
+            <span class="actionlink">
+                <a href='#' onclick='branchall()'>
+                    <?php echo translate("expand all");?></a> |
+                <a href='#' onclick='unbranchall()'>
+                    <?php echo translate("collapse all");?></a>
+            </span><br>
+<?php
+        }
 ?>
         <ul class="<?php echo $_view ?>">
 <?php
@@ -207,5 +220,7 @@
 ?>
     </div>
 <?php
+    } // if show_orig
+    echo $page_html;
     require_once("footer.inc.php");
 ?>
