@@ -136,6 +136,8 @@ if ($action == "confirm") {
             <label for="comment"><?php echo translate("comment") ?></label> 
             <textarea name="comment" rows="8" cols="80"><?php echo $comment->get("comment") ?></textarea><br>
             <input type="submit" value="<?php echo translate($action, 0) ?>">
+            <h2><?php echo translate("smileys you can use"); ?></h2>
+            <?php echo get_smiley_overview(); ?>
         </form>
     </div>
 
