@@ -135,6 +135,7 @@ ul.thumbs li img {
 }
 
 ul.thumbs li div {
+    left: 5%;
     position: absolute;
     bottom: 0px;
     text-align: center;
@@ -146,6 +147,10 @@ ul.list {
     list-style: none;
     }
 
+ul.list li.alternate {
+    background-color: <?php echo $TITLE_BG_COLOR ?>;
+    }
+
 ul.tree {
     clear: both;
     list-style: none;
@@ -163,7 +168,36 @@ ul.tree ul ul {
 
 ul.thumbs a {
     text-align: center;
+    text-decoration: none; 
     }
+
+ul.admin {
+    list-style: none;
+    }
+
+ul.admin li {
+    width: 110px;
+    height: 110px;
+    display: block;
+    margin: 3px;
+    float: left;
+    clear: none;
+    text-align: center;
+    }
+
+ul.admin a {
+    text-decoration: none;
+    padding: 5px;
+    width: 100px;
+    height: 100px;
+    display: block;
+    }
+
+ul.admin a:hover {
+    background: <?php echo $BREADCRUMB_BG_COLOR ?>;
+    border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>;
+    }
+
 /* Form properties */
 form    {
     margin: 0 0 0 0;
@@ -199,6 +233,26 @@ form#ratingform select {
     margin-right: 5px;
     }
 
+/* Form to add a page to a pageset */
+form.addpage {
+    width: auto;
+    text-align: right;
+    }
+form.addpage input[type="submit"]   {
+    display: inline;
+    margin: 15px;
+    vertical-align: middle;
+    }
+form.addpage select {
+    display: inline;
+    vertical-align: middle;
+}
+form.addpage label {
+    vertical-align: middle;
+    float: none;
+    display: inline;
+}
+
 ul.autocompdropdown {
     position: relative;
     background: <?php echo $PAGE_BG_COLOR ?>;
@@ -320,7 +374,7 @@ div.breadcrumb li.firstdots:before {
     }
 
 /* Main page */
-.main, .info, .letter, div#selection   {
+.main, .info, .letter, .page, div.map, div#selection   {
     background: <?php echo $TABLE_BG_COLOR ?>;
     font-size: medium;
     width: 100%;
@@ -330,6 +384,52 @@ div.breadcrumb li.firstdots:before {
     clear: both;
     }
 
+div.map {
+    height: 450px;
+    }
+
+div.map small {
+    display: block;
+    /* used in infoBubble */
+    font-size: x-small;
+    }
+
+div.minimap {
+    float: right;
+    right: 10px;
+    width: 300px;
+    height: 300px;
+    }
+
+div.mapinfo {
+    float: left;
+}
+
+span.showhide {
+    font-size: small;
+    text-align: right;
+    }
+
+div.timedetail {
+    display: none;
+    border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>;
+    background: white;
+    width: 100%;
+    }
+
+div.timedetail dd {
+    width: 40%;
+    }
+
+div.timedetail dt {
+    width: 40%;
+    }
+
+div.timedetail h3 {
+    background: <?php echo $TITLE_BG_COLOR ?>;
+    color: <?php echo $TITLE_FONT_COLOR ?>;
+    font-size: large;
+}
 p.main, p.info {
     padding: 4px;
     }
@@ -371,7 +471,33 @@ table.reports {
     float: left;
     padding: 10px 5px 20px 5px;
 }
+
+table.pages, table.pagesets {
+    width: 100%;
+    }
+
+div.smileys {
+    border: 1px solid black;
+    clear: right;
+    }
     
+div.smileys div {
+    float: left;
+    width: 70px;
+    height: 20px;
+}
+
+div.smileys span {
+    font-size: 8pt;
+    vertical-align: middle;
+    }
+
+div.smileys img {
+    float: left;
+    margin: 2px;
+    margin-right: 4px;
+    }
+
 /* This is the bar that shows the number of photos for each rating */
 div.ratings   {
     float: left;
@@ -516,20 +642,28 @@ table#permissions td.permremove {
     }
 
 /* Previous and next links above a photo */
-div#prev, div#next, div#pagelink, div#photohdr  {
+div.prev, div.next, div.pagelink, div.photohdr  {
     margin-bottom: 2px;
     margin-top: 30px;
     font-size: small;
     float: left;
     }
 
-div#prev    { 
+div.prev a, div.next a, div.pagelink a {
+    text-decoration: none;
+    }
+
+div.prev a:hover, div.next a:hover, div.pagelink a:hover {
+    text-decoration: underline;
+    }
+
+div.prev    { 
     width: 20%;
     float: left; 
     text-align: left 
     }
     
-div#next    {
+div.next    {
     width: 20%;
     float: right;
     text-align: right;
@@ -538,13 +672,13 @@ div#next    {
 
 
 /* Page links */
-div#pagelink,
-div#photohdr {
+div.pagelink,
+div.photohdr {
     text-align: center;
     width: 60%;
     }
     
-#currentpage    {
+.currentpage    {
     color: red;
     font-weight: bold;
     }
@@ -636,7 +770,7 @@ div.thumbnail   {
     margin: 2px;
     padding: 5px;
     }
-    
+
 div.comment {
     border: 1px solid <?PHP echo $TABLE_BORDER_COLOR ?>;
     background: transparent;
@@ -703,19 +837,19 @@ label, dt, dd    {
     font-size: medium; 
     padding-left: 4px;
     padding-right: 4px;
+    min-height: 1.3em;
     }
 
 dd {
     float: left;
-    clear: right;
-    margin-top: 5px;
-    margin-bottom: 5px;
+    width: 55%;
+    margin: 5px;
     }
 
 dt {
     clear: left;
     float: left;
-    width: 10em;
+    width: 40%;
     font-weight: bold;
     text-align: right;
     margin-top: 5px;
@@ -729,10 +863,6 @@ dl  {
     border: 1px solid transparent;
     }
 
-dl.prefs dt {
-    width: 25em;
-    }
-
 dl#allexif {
     display: none;
     width: 100%;
@@ -742,7 +872,7 @@ dl#allexif dl {
     width: 100%
     }
 
-label, table#credits th {
+label, table.credits th {
     text-align: right;
     vertical-align: top;
     font-weight: bold;
@@ -774,14 +904,14 @@ fieldset  {
     clear: right;
     }
 
-fieldset.editphotos  {
+fieldset.editphotos, fieldset.map  {
     margin-top: 10px;
     margin-bottom: 5px;
     padding-bottom: 20px;
     border: 1px solid <?php echo $PAGE_BG_COLOR ?>;
     }
 
-fieldset.editphotos legend {
+fieldset.editphotos legend, fieldset.map legend {
     clear: both;
     display: block;
     left: 2em;
@@ -897,12 +1027,12 @@ input, select {
     }
 
 table#users,
-table#credits {
+table.credits {
     width: 100%;
     }
 
 table#users td, 
-table#credits td { 
+table.credits td { 
     margin: 2px;
     }
 
@@ -938,6 +1068,48 @@ div#rotate input[type="submit"] {
     margin-right: auto;
     }
 
+div.page-preview {
+    border: 1px solid black;
+    width: 80%;
+    max-height: 600px;
+    min-width: 600px;
+    overflow: scroll;
+    background: <?php echo $TABLE_BG_COLOR ?>;
+    font-size: medium;
+    border-spacing: 0px;
+    padding: 10px;
+    border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>;
+    clear: both;
+    }
+
+div.page h1, div.page-preview h1 {
+    position: relative;
+    left: -10px;
+    margin: 0;
+    width: 100%;
+    border-left: 0px;
+    border-right: 0px;
+    background: <?php echo $TITLE_BG_COLOR ?>;
+    font-size: large;
+    text-align: center;
+
+   }
+
+div.page h2, div.page-preview h2 {
+    text-align: center;
+    border-bottom: 1px solid black;
+    }
+
+div.page h3, div.page-preview h3 {
+    text-align: left;
+    }
+
+div.page div.background {
+    margin: -10px;
+    padding: 10px;
+    width: 100%;
+    }
+
 /* Styles for calendar */
 
 .calendar { 
