@@ -15,12 +15,17 @@
  * along with Zoph; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+        if ($num_photos) {
+            $title_bar = sprintf(translate("photo %s of %s"),  ($offset + 1) , $num_photos);
+        } else {
+            $title_bar = translate("photo");
+        }
 ?>
           <h1>
 <?php
           echo create_actionlinks($actionlinks);
+          echo $title_bar;
 ?>
-          <?php echo translate("photo") ?>
           </h1>
 <?php
           require_once("selection.inc.php");
@@ -72,13 +77,13 @@
     }
 ?>
 
-                <div id="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
-                <div id="photohdr">
+                <div class="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
+                <div class="photohdr">
                   <?php echo $photo->get_fullsize_link($photo->get("name"),$FULLSIZE_NEW_WIN) ?> :
                   <?php echo $photo->get("width") ?> x <?php echo $photo->get("height") ?>,
                   <?php echo $photo->get("size") ?> <?php echo translate("bytes") ?>
                 </div>
-                <div id="next"><?php echo $next_link ? "[ $next_link ]" : "&nbsp;" ?></div>
+                <div class="next"><?php echo $next_link ? "[ $next_link ]" : "&nbsp;" ?></div>
             <?php echo $photo->get_fullsize_link($photo->get_midsize_img(),$FULLSIZE_NEW_WIN) ?>
 <?php
     }
@@ -96,12 +101,39 @@
         }
 ?>
           <br>
+          <fieldset class="map">
+                <legend><?php echo translate("map") ?></legend>
+<?php
+        if(JAVASCRIPT && MAPS) {
+?>
+            <div class="minimap" id="map"></div>
+<?php
+        }
+?>
+            <div class="mapinfo">
+                <label for="lat"><?php echo translate("lattitude") ?></label>
+                <?php echo create_text_input("lat", $photo->get("lat"), 10, 10) ?><br>
+                <label for="lat"><?php echo translate("longitude") ?></label>
+                <?php echo create_text_input("lon", $photo->get("lon"), 10, 10) ?><br>
+                <label for="mapzoom"><?php echo translate("zoom level") ?></label>
+                <?php echo create_zoom_pulldown($photo->get("mapzoom")) ?><br>
+             </div>
+<?php
+        if(JAVASCRIPT && MAPS) {
+            echo create_map_js();
+            echo $photo->get_mapping_js($user, true);
+        }
+?>
+          </fieldset>
           <label for="date"><?php echo translate("date") ?></label>
           <?php echo create_text_input("date", $photo->get("date"), 12, 10) ?>
           <span class="inputhint">YYYY-MM-DD</span><br>
           <label for="time"><?php echo translate("time") ?></label>
           <?php echo create_text_input("time", $photo->get("time"), 10, 8) ?>
           <span class="inputhint">HH:MM:SS</span><br>
+          <label for="time_corr"><?php echo translate("time correction") ?></label>
+          <?php echo create_text_input("time_corr", $photo->get("time_corr"), 10, 8) ?>
+          <span class="inputhint"><?php echo translate("in minutes") ?></span><br>
           <label for="view"><?php echo translate("view") ?></label>
           <?php echo create_text_input("view", $photo->get("view"), 40, 64) ?>
           <span class="inputhint"><?php echo sprintf(translate("%s chars max"), "64") ?></span><br>
