@@ -16,11 +16,10 @@
 function branch(obj) {
     obj.nextSibling.nextSibling.style.display="block";
     obj.innerHTML="-&nbsp;";
-    obj.onclick=unbranch;
+    obj.onclick=closebranch;
     }
 
 function unbranch(obj) {
-    obj=this;
     obj.nextSibling.nextSibling.style.display="none";
     obj.innerHTML="+&nbsp;";
     obj.onclick=openbranch;
@@ -29,3 +28,21 @@ function unbranch(obj) {
 function openbranch() {
     branch(this);
     }
+
+function closebranch() {
+    unbranch(this);
+    }
+
+function unbranchall() {
+    nodes=getElementsByClass('treenode');
+    for(i in nodes) {
+        unbranch(nodes[i]);
+    }
+}
+
+function branchall() {
+    nodes=getElementsByClass('treenode');
+    for(i in nodes) {
+        branch(nodes[i]);
+    }
+}
