@@ -25,6 +25,7 @@ class photo extends zoph_table {
     var $location;
 
     function photo($id = 0) {
+        if($id && !is_numeric($id)) { die("photo_id must be numeric"); }
         parent::zoph_table("photos", array("photo_id"), array(""));
         $this->set("photo_id",$id);
     }
@@ -357,7 +358,7 @@ class photo extends zoph_table {
         }
 
         $size_string = " width=\"$width\" height=\"$height\"";
-        $alt = $this->get("title");
+        $alt = escape_string($this->get("title"));
 return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . " alt=\"$alt\"" . ">";
 }
 
@@ -821,13 +822,14 @@ echo ("<br>\noutString:<br>\n" . $out_string);
     }
 
     function get_display_array() {
+        $datetime=$this->get_time();
         return array(
             translate("title") => $this->get("title"),
             translate("location") => $this->location
                 ? $this->location->get_link() : "",
             translate("view") => $this->get("view"),
-            translate("date") => create_date_link($this->get("date")),
-            translate("time") => $this->get("time"),
+            translate("date") => create_date_link($datetime[0]),
+            translate("time") => $this->get_time_details($datetime[1]),
             translate("photographer") => $this->photographer
                 ? $this->photographer->get_link() : ""
         );
@@ -875,6 +877,105 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             "Level" => create_text_input("level", $this->level, 4, 2));
     }
 
+    function get_time($timezone=null) {
+        if(minimum_version("5.1.0")) {
+            if(valid_tz($timezone)) {
+                $place_tz=new TimeZone($timezone);
+            } else { 
+                $this->lookup_location();
+                $loc=$this->location;
+                if($loc && valid_tz($loc->get("timezone"))) {
+                    $place_tz=new TimeZone($loc->get("timezone"));
+                } 
+            }
+            if(valid_tz(CAMERA_TZ)) {
+                $camera_tz=new TimeZone(CAMERA_TZ);
+            }    
+                
+            if(!$place_tz && $camera_tz) {
+                // Camera timezone is known, place timezone is not.
+                $place_tz=$camera_tz;
+            } else if ($place_tz && !$camera_tz) {
+                // Place timezone is known, camera timezone is not.
+                $camera_tz=$place_tz;
+            }
+            
+            $camera_time=new Time(
+                $this->get("date") . " " .
+                $this->get("time"),
+                $camera_tz);
+            $place_time=new Time(
+                $this->get("date") . " " .
+                $this->get("time"),
+                $place_tz);
+            $corr=$this->get("time_corr");
+            if($corr) {
+                $place_time->modify($corr . " minutes");
+            }
+            
+            $date=$place_time->format(DATE_FORMAT);
+            $time=$place_time->format(TIME_FORMAT);
+        } else {
+            // Timezone support was introduced in PHP 5.1
+            // so we'll just return date and time as they are
+            // stored in db.
+            $date=$this->get("date");
+            $time=$this->get("time");
+        }
+        return array($date,$time);
+    }
+
+    function get_time_details($content, $open=false) {
+        $html="&nbsp;";
+        if ($open) {
+            $html.="<span onclick=\"unbranch(this)\">-&nbsp;</span>";
+        } else {
+            $html.="<span onclick=\"branch(this)\">+&nbsp;</span>";
+        }
+        $html.="<span class='showhide'>" . $content . "</span>";
+        $html.="<div class='timedetail'>\n<dl>\n";
+        $html.="<h3>" . translate("database") . "</h3>\n";
+        $html.="<dt>" . translate("date") . "</dt>\n";
+        $html.="<dd>" . $this->get("date") . "</dd>\n";
+        $html.="<dt>" . translate("time") . "</dt>\n";
+        $html.="<dd>" . $this->get("time") . "</dd>\n";
+        $html.="<dt>" . translate("timezone") . "</dt>\n";
+        if(valid_tz(CAMERA_TZ)) {
+            $html.="<dd>" . CAMERA_TZ . "</dd>\n<br>\n";
+        } else {
+            $html.="<dd><i>" . translate ("not set") . "</i></dd><br>\n";
+        }
+        $corr=$this->get("time_corr");
+        if($corr) {
+            $html.="<dt>" . translate("correction") . "</dt>\n";
+            $html.="<dd>" . $corr . " " . translate("minutes") . "</dd>\n";
+        }
+        $html.="<br>";
+        $this->lookup_location();
+        $place=$this->location;
+        if($place) {
+            $html.="<h3>" . translate("location") . "</h3>\n";
+            $html.="<dt>" . translate("location") . "</dt>\n";
+            $html.="<dd>" . $place->get("title") . "</dd>\n";
+            $html.="<dt>" . translate("timezone") . "</dt>\n";
+            $tz=$place->get("timezone");
+            $datetime=$this->get_time();
+            if($tz) {
+                $html.="<dd>" . $tz . "</dd>\n<br>\n";
+            } else {
+                $html.="<dd><i>" . translate ("not set") . "</i></dd><br>\n";
+            }
+        }
+        $html.="<h3>" .translate("calculated time") . "</h3>\n";
+        $html.="<dt>" . translate("date") . "</dt>\n";
+        $html.="<dd>" . $datetime[0] . "</dd>\n";
+        $html.="<dt>" . translate("time") . "</dt>\n";
+        $html.="<dd>" . $datetime[1] . "</dd>\n";
+        $html.="</dl>\n<br>\n</div>";
+        return $html;
+    }
+
+
     function get_comments() {
         $sql = "select comment_id from " . DB_PREFIX . "photo_comments where" .
             " photo_id = " .  $this->get("photo_id");
@@ -904,10 +1005,10 @@ echo ("<br>\noutString:<br>\n" . $out_string);
     }
     function get_relation_desc($photo_id_2) {
         $sql = "select desc_1 from " . DB_PREFIX . "photo_relations where" .
-            " photo_id_2 = " . $this->get("photo_id") . " and " .
+            " photo_id_2 = " . escape_string($this->get("photo_id")) . " and " .
             " photo_id_1 = " . escape_string($photo_id_2) . 
             " union select desc_2 from " . DB_PREFIX . "photo_relations where" .
-            " photo_id_1 = " . $this->get("photo_id") . " and " .
+            " photo_id_1 = " . escape_string($this->get("photo_id")) . " and " .
             " photo_id_2 = " . escape_string($photo_id_2) . " limit 1";
         $result=mysql_query($sql)
             or die("Could not get description for related photo:<br><i>$sql</i>");
@@ -986,6 +1087,75 @@ echo ("<br>\noutString:<br>\n" . $out_string);
         }
         return $return;
     }
+
+    function get_quicklook($user) {
+        $title=escape_string($this->get("title"));
+        $file=$this->get("name");
+
+        if($title) {
+            $html="<h2>" . $title . "</h2><p>" . $file . "</p>";
+        } else {
+            $html="<h2>" . $file . "</h2>";
+        }    
+        $html.=$this->get_thumbnail_link() .
+          "<p><small>" . 
+          $this->get("date") . " " . $this->get("time") . "<br>" .
+          translate("by",0) . " " . $this->photographer->get_link(1) . "<br>" .
+          "</small></p>";
+        return $html;
+    }
+
+    function get_marker($user, $check_loc=true) {
+        $icon=ICONSET . "/geo-photo.png";
+        $js=parent::get_marker($user, $icon); 
+        if(!$js && $check_loc) {
+            $loc=$this->location;
+            if($loc) {
+                $js=$loc->get_marker($user); 
+            }
+        }
+        if($js) {
+            return($js);
+        } else {
+            return null;
+        }
+    }
+
+    function get_mapping_js($user,$edit=false) {
+         return parent::get_mapping_js($user, ICONSET . "/geo-photo.png", $edit);
+    }
+
+    function get_near($distance, $limit=100, $entity="km") { 
+        $lat=$this->get("lat");
+        $lon=$this->get("lon");
+
+        if($lat && $lon) {
+            // If lat and lon are not set, don't bother trying to find
+            // near photos
+            if($entity=="miles") {
+                $distance=$distance * 1.609344;
+            }
+            if($limit) {
+                $lim=" limit 0,". $limit;
+            }
+            $sql="select photo_id, (6371 * acos(" .
+                "cos(radians(" . $lat . ")) * " .
+                "cos(radians(lat) ) * cos(radians(lon) - " .
+                "radians(" . $lon . ")) +" . 
+                "sin(radians(" . $lat . ")) * " .
+                "sin(radians(lat)))) AS distance from " .
+                DB_PREFIX . "photos " .
+                "having distance <= " . $distance . 
+                " order by distance" . $lim;
+
+            $near=get_records_from_query("photo", $sql);
+            return $near;
+        } else {
+            return null;
+        }
+    }
+
+
 }
 
 function get_photo_sizes_sum() {
@@ -1139,5 +1309,4 @@ function ImageStringWrap($image, $font, $x, $y, $text, $color, $maxwidth) {
         $y += $fontheight;
     }
 }
-
 ?>
