@@ -53,7 +53,6 @@
         if (!$_off)  { $_off = 0; }
         $offset = $_off;
 
-        $thumbnails;
         $num_photos = get_photos($request_vars, $offset, 1, $thumbnails, $user);
 
         $num_thumbnails = sizeof($thumbnails);
@@ -76,6 +75,9 @@
             $photo = new photo();
         }
     }
+    if(!$user->is_admin()) {
+        $permissions = $user->get_permissions_for_photo($photo_id);
+    }
 
     if (isset($offset)) {
         $ignore = array("_off", "_action");
@@ -112,6 +114,18 @@
         }
     }
 
+   if ($_action == "lightbox") {
+        $photo->add_to_album($user->get("lightbox_id"));
+        $action = "display";
+    }
+    else if ($_action == "rate") {
+        if (ALLOW_RATINGS) {
+            $rating = getvar("rating");
+            $photo->rate($user->get("user_id"), $rating);
+        }
+        $action = "display";
+    }
+
     if (!$user->is_admin()) {
         if ($_action == "new" || $_action == "insert" ||
             $_action == "delete" || $_action == "confirm") {
@@ -120,7 +134,6 @@
             header("Location: " . add_sid("zoph.php"));
         }
 
-        $permissions = $user->get_permissions_for_photo($photo_id);
         if (!$permissions) {
             $photo = new photo(-1); // in case redirect fails
             header("Location: " . add_sid("zoph.php"));
@@ -164,24 +177,7 @@
         $actionlinks["return"]="photo.php?_action=display&amp;" . $return_qs;
         $_action = "edit";
     }
-
-    // 2005-04-10 --JCT
-    //
-    // moved from below so they are allowed
-    // prior to $user->is_admin() check
-    //
-    if ($_action == "lightbox") {
-        $photo->add_to_album($user->get("lightbox_id"));
-        $action = "display";
-    }
-    else if ($_action == "rate") {
-        if (ALLOW_RATINGS) {
-            $rating = getvar("rating");
-            $photo->rate($user->get("user_id"), $rating);
-        }
-        $action = "display";
-    }
-
+   
     if ($_action == "edit") {
         $actionlinks["return"]="photo.php?_action=display&amp;" . $return_qs;
         unset($actionlinks["cancel"]);
@@ -284,9 +280,10 @@ require_once("header.inc.php");
     else if ($action == "display") {
         unset($actionlinks["cancel"]);
         unset($actionlinks["return"]);
-        $title_bar = translate("photo");
         if ($num_photos) {
-            $title_bar .= " " . ($offset + 1) . " of $num_photos";
+            $title_bar = sprintf(translate("photo %s of %s"),  ($offset + 1) , $num_photos);
+        } else {
+            $title_bar = translate("photo");
         }
 ?>
           <h1>
@@ -319,8 +316,8 @@ require_once("header.inc.php");
 <?php
         }
 ?>
-        <div id="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
-        <div id="photohdr">
+        <div class="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
+        <div class="photohdr">
 <?php
         if ($up_link) {
 ?>
@@ -332,7 +329,7 @@ require_once("header.inc.php");
                   <?php echo $photo->get("width") ?> x <?php echo $photo->get("height") ?>,
             <?php echo $photo->get("size") ?> <?php echo translate("bytes") ?>
             </div>    
-            <div id="next"><?php echo $next_link ? "[ $next_link ]" : "&nbsp;" ?></div>
+            <div class="next"><?php echo $next_link ? "[ $next_link ]" : "&nbsp;" ?></div>
             <?php echo $photo->get_fullsize_link($photo->get_midsize_img(),$FULLSIZE_NEW_WIN) ?>
 <?php
         if (($user->is_admin() || $user->get("browse_people")) && $people_links = get_photo_person_links($photo)) {
@@ -454,18 +451,26 @@ require_once("header.inc.php");
     }
     else if ($action == "confirm") {
 ?>
-          <h1><?php echo translate("photo") ?></h1>
+          <h1><?php echo translate("photo")?></h1>
           <div class="main">
 <?php
-    echo create_actionlinks($actionlinks);
-?>
-            <?php echo sprintf(translate("Confirm deletion of '%s'"), $photo->get("name")) ?>
-
-<?php
+        echo create_actionlinks($actionlinks);
+        echo sprintf(translate("Confirm deletion of '%s'"), $photo->get("name"));
+        echo $photo->get_midsize_img();
     }
     else {
 require_once("edit_photo.inc.php");
     }
 ?>
 </div>
+<?php
+      if(JAVASCRIPT && MAPS && $_action=="display") {
+?>
+        <div id="map" class="map"></div>
+<?php
+        echo create_map_js();
+        echo get_markers($photo->get_near(100), $user);
+      }
+?>
+
 <?php require_once("footer.inc.php"); ?>
