@@ -185,12 +185,20 @@
 //        }
 ?>
        <br>
-<?php include "pager.inc.php" ?>
 <?php
+        echo pager($offset, $num_photos, $num_pages, $cells, $MAX_PAGER_SIZE, $PHP_SELF, $request_vars, "_off");
     } // if photos
 ?>
        <br>
 
       </div>
-
+<?php
+      if(JAVASCRIPT && MAPS) {
+?>
+        <div id="map" class="map"></div>
+<?php
+        echo create_map_js();
+        echo get_markers($thumbnails, $user);
+      }
+?>
 <?php require_once("footer.inc.php"); ?>
