@@ -38,6 +38,7 @@
         $place = new place($parent_place_id);
     }
     $place->lookup();
+    $obj=&$place;
     $ancestors = $place->get_ancestors();
     $children = $place->get_children(null, "title");
 
@@ -62,6 +63,8 @@
     if ($user->is_admin()) {
         include("selection.inc.php");
     }
+    include("show_page.inc.php");
+    if($show_orig) {
 ?>
     <div class="main">
 <?php
@@ -119,7 +122,9 @@
     if ($user->get("detailed_places") || $user->is_admin()) {
         echo $place->to_html();
         if ($place->get("notes")) {
+            echo "<p>";
             echo $place->get("notes");
+            echo "</p>";
         }
     }
     else {
@@ -128,6 +133,9 @@
     if ($place->get("place_description")) {
        echo $place->get("place_description");
     }
+    if ($place->get("timezone")) {
+        printf("<p><b>%s:</b> %s</p>", translate("timezone"), $place->get("timezone"));
+    }
 ?>
     <br><br>
 <?php
@@ -175,6 +183,16 @@
         <?php echo translate("There are no photos") ?> <?php echo $fragment . ".<br>\n"; 
     }
     if ($children) {
+        if($_view=="tree" && JAVASCRIPT) {
+?>
+            <span class="actionlink">
+                <a href='#' onclick='branchall()'>
+                    <?php echo translate("expand all");?></a> | 
+                <a href='#' onclick='unbranchall()'>
+                    <?php echo translate("collapse all");?></a>
+            </span><br>
+<?php
+        }
 ?>
         <ul class="<?php echo $_view ?>">
 <?php
@@ -224,5 +242,14 @@
 ?>
     </div>
 <?php
+      if(JAVASCRIPT && MAPS) {
+?>
+        <div id="map" class="map"></div>
+<?php
+        echo create_map_js();
+        echo $place->get_mapping_js($user);
+      }
+    } // if show_orig
+    echo $page_html;
     require_once("footer.inc.php");
 ?>
