@@ -668,7 +668,8 @@ function create_zipfile($photos, $maxsize, $filename, $filenum, $user) {
         $zip=new ZipArchive();
         $tempfile="/tmp/zoph_" . $user->get("user_id") . "_" . $filename ."_" . $filenum . ".zip";
         @unlink($tempfile);
-        if ($zip->open($tempfile, ZIPARCHIVE::CREATE)!==TRUE) {
+        // ZIPARCHIVE::CREATE is not available in PHP4, but resolves to 1
+        if ($zip->open($tempfile, 1)!==TRUE) {
             die("cannot open $tempfile\n");
         }
         $count=sizeof($photos);
@@ -745,4 +746,101 @@ function watermark_image($orig, $watermark, $positionX = "center", $positionY =
     imagedestroy($wm);
     return $orig;
 }
+
+function pager($current, $total, $num_pages, $page_size, $max_size, $url, $request_vars, $var) {
+    $page_num = floor($current / $page_size) + 1;
+    if ($current > 0) {
+        $new_offset = max(0, $current - $page_size);
+        $html="<div class='prev'>\n";
+        $html.="[ <a href='" . $url . "?";
+        $html.=update_query_string($request_vars, $var, $new_offset);
+        $html.="'>" . translate("Prev") . "</a> ]\n";
+        $html.="</div>\n";
+    } else {
+        $html.="<div class='prev'>&nbsp;</div>\n";
+    }
+
+    if ($num_pages > 1) {
+        $html.="<div class='pagelink'>[ ";
+        $mid_page = floor($max_size / 2);
+        $page = $page_num - $mid_page;
+        if ($page <= 0) { $page = 1; }
+
+        $last_page = $page + $max_size - 1;
+        if ($last_page > $num_pages) {
+            $page = $page - $last_page + $num_pages;
+            if ($page <= 0) { $page = 1; }
+            $last_page = $num_pages;
+        }
+
+        if ($page > 1) {
+            $html.="<a href='" . $url . "?";
+            $html.=update_query_string($request_vars, $var, 0). "'>1</a> ...";
+        }
+
+        while ($page <= $last_page) {
+            $new_offset = ($page - 1) * $page_size;
+            $new_query_string=update_query_string($request_vars, $var, $new_offset);
+            $currentpage=$page == $page_num ? " class='currentpage'" : "";
+            $html.="&nbsp;<a href='" . $url . "?" . $new_query_string . "'>";
+            $html.="<span " . $currentpage . ">" . $page . "</span></a>&nbsp;";
+            $page++;
+        }
+
+        if ($page <= $num_pages) {
+            $new_query_string=update_query_string($request_vars, $var, ($num_pages-1) * $page_size);
+            $html.="... <a href='" . $url . "?" . $new_query_string . "'>";
+            $html.=$num_pages . "</a>";
+        }
+        $html.=" ]</div>\n\n";
+    } else {
+        $html.="<div class=\"pagelink\">&nbsp;</div>\n";
+    }
+    if ($total >  $current + $page_size) {
+        $new_offset = $current + $page_size;
+        $new_query_string=update_query_string($request_vars, $var, $new_offset);
+        $html.="<div class='next'>";
+        $html.="[ <a href='" . $url . "?" . $new_query_string . "'>";
+        $html.=translate("Next") . "</a> ]";
+        $html.="</div>";
+    } else {
+        $html.="<div class=\"next\">&nbsp;</div>\n";
+    }
+    return $html;
+}
+function get_markers($objects, $user) {
+    $js="<script type='text/javascript'>\n";
+    $markers=array();
+    if($objects) {
+        foreach($objects as $object) {
+            $object->lookup();
+            $marker=$object->get_marker($user);
+            if($marker) {
+                $markers[]=$marker;
+            }
+        }
+        // if multiple photos are taken in the same place, that place 
+        // is multiple times in the array, let's remove doubles:
+        $markers=array_unique($markers);
+        foreach($markers as $marker) {
+            $js.=$marker;
+        }
+        $js.="  mapstraction.autoCenterAndZoom();\n";
+        $js.="</script>";
+    }
+    if(count($markers)>0) {
+        // only return the javascript if anything is in there, to
+        // prevent an empty <script> tag.
+        return $js;
+    } else {
+        return null;
+    }
+}
+
+function create_map_js($provider=MAPS, $map="map") {
+    $js="<script type='text/javascript'>\n" .
+        "  createMap('" . $map . "','" . $provider . "');\n" .
+        "</script>";
+    return $js;
+}
 ?>
