@@ -74,7 +74,7 @@ class zoph_table {
             if (DEBUG > 2) { echo "<b>$key</b> = $val<br>\n"; }
 
             // ignore empty keys or values unless the field must be set.
-            if ((!in_array($key, $this->not_null)) && (empty($key) || $val == "")) { continue; }
+            if ((!in_array($key, $this->not_null)) && (empty($key) )) { continue; }
 
             if ($prefix) {
                 if (strpos($key, $prefix) === 0) {
@@ -189,15 +189,12 @@ class zoph_table {
             else if ($value == "now()") {
                 /* Lastnotify is normaly set to "now()" and should not be escaped */
                 $values .=  $value ;
-            }
-	    else if ($value == "" && in_array($name, $this->not_null)) {
-	    	die("<p class='error'><b>$name</b> may not be empty</p>");
-	    }
-            else if ($value != "null") {
+            } else if ($value =="" && in_array($name, $this->not_null)) {
+	    	    die("<p class='error'><b>$name</b> may not be empty</p>");
+	        } else if ($value !== "") {
                 $values .= "'" . escape_string($value) . "'";
-            }
-            else {
-                $values .= $value;
+            } else {
+                $values .= "null";
             }
 
         }
@@ -280,18 +277,14 @@ class zoph_table {
 
             if ($name == "password") {
                 $values .= "$name = password('" . escape_string($value) . "')";
-            }
-            else if ($value == "now()" ) {
+            } else if ($value == "now()" ) {
                 $values .= "$name = " . $value . "";
-            }
-	    else if ($value == "" && in_array($name, $this->not_null)) {
-	    	die("<p class='error'><b>$name</b> may not be empty</p>");
-	    }
-            else if ($value != "null") {
+            } else if ($value == "" && in_array($name, $this->not_null)) {
+	    	    die("<p class='error'><b>$name</b> may not be empty</p>");
+	        } else if ($value !== "") {
                 $values .= "$name = '" . escape_string($value) . "'";
-            }
-            else {
-                $values .= "$name = $value";
+            } else {
+                $values .= "$name = null";
             }
         }
 
@@ -361,6 +354,45 @@ class zoph_table {
         return $ea;
     }
 
+    function get_mapping_js($user,$icon,$edit=false) {
+        $marker=true;
+        $lat=$this->get("lat");
+        $lon=$this->get("lon");
+        $zoom=$this->get("mapzoom");
+        if(!$lat && !$lon) { $marker=false; }
+        if(!$lat) { $lat=0; }
+        if(!$lon) { $lon=0; }
+        if(!$zoom) { $zoom=2; }
+        $js="<script type='text/javascript'>\n" .
+            "  var center=new LatLonPoint(" .
+                $lat . "," .
+                $lon . ");\n" .
+            "  var zoomlevel=" . $zoom . ";\n" .
+            "  mapstraction.setCenterAndZoom(center,zoomlevel);\n";
+         if ($marker ) {
+            $js.="  createMarker(" . $lat . "," . $lon . ",'" . $icon . "',null, null);\n";
+         }
+         if ($edit) {
+            $js.="  setUpdateHandlers();\n";
+         }
+            $js.="</script>";
+        return $js;
+    }
+
+    function get_marker($user, $icon) {
+        $lat=$this->get("lat");
+        $lon=$this->get("lon");
+        if($lat && $lon) {
+            $quicklook=$this->get_quicklook($user);
+            return "  createMarker(" . $lat . "," . $lon . ", '" . $icon .
+                    "','" .  escape_string($title) . "','" . 
+                    $quicklook . "');\n";
+        } else {
+            return null;
+        }
+    }
+
+
 }
 
 /*
@@ -559,6 +591,10 @@ function get_xml($class, $search) {
         $tree=true;
     }
 
+    if($class=="timezone") {
+        $tz=new TimeZone("UTC");
+        return $tz->get_xml($search);
+    }
     if (class_exists($class)) {
         $obj=new $class;
         $rootname=$obj->xml_rootname();
